# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl test.pl'

######################### We start with some black magic to print on failure.

# Change 1..1 below to 1..last_test_to_print .
# (It may become useful if the test is moved to ./t subdirectory.)

BEGIN { $| = 1; print "1..7\n"; }
END {print "not ok 1\n" unless $loaded;}
use TM;
$loaded = 1;
print "ok 1\n";
my $rv;

######################### End of black magic.

# Insert your test code below (better if it prints "ok 13"
# (correspondingly "not ok 13") depending on the success of chunk 13
# of the test code):

my $tm = TM::TopicMap->new();
if(defined $tm) { print "ok 2\n"; }
else { print "not ok 2\n"; }


$rv = $tm->load_string("<topicMap></topicMap>", "xtm_simple","xml");
if(defined $rv) { print "ok 3\n"; }
else { print "not ok 3\n"; }

$rv = $tm->load_string("<topicMap><topic id=\"t1\"/></topicMap>", "xtm_simple","xml");
if(defined $rv) { print "ok 4\n"; }
else { print "not ok 4\n"; }
undef $tm;

$tm = TM::TopicMap->new();
$rv = $tm->load_string(
	qq{<topicMap>
	   <topic id="t1">
	   <subjectIdentity>
	   <resourceRef xlink:href="http://docs.org/doc1.pdf" />
	   <resourceRef xlink:href="http://docs.org/doc2.pdf" />
	   </subjectIdentity>
	   </topic>

	</topicMap>},
	 "xtm_simple","xml");
if(!defined $rv) { print "ok 5\n"; }
else { print "not ok 5\n"; }
undef $tm;


$tm = TM::TopicMap->new();
$rv = $tm->load_string(
	qq{<topicMap>
	   <topic id="t1">
	   <subjectIdentity>
	   <resourceRef xlink:href="http://docs.org/doc1.pdf" />
	   </subjectIdentity>
	   </topic>
	</topicMap>},
	 "xtm_simple","xml");
if(defined $rv) { print "ok 6\n"; }
else { print "not ok 6\n"; }

my $t = $tm->get_topic("http://www.gooseworks.org/disclosures/SAM.xml::SubjectAddress","http://docs.org/doc1.pdf");
my $scr = $tm->get_property($t,"http://www.gooseworks.org/disclosures/SAM.xml::SubjectAddress");
if($scr eq "http://docs.org/doc1.pdf") { print "ok 7\n"; }
else { print "not ok 7\n"; }

undef $tm;
